@@ -78,7 +78,6 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
     m_systemBookmarksIndexes(),
     m_bookmarkedItems(),
     m_hiddenItemToRemove(-1),
-    m_saveBookmarksTimer(0),
     m_updateBookmarksTimer(0),
     m_storageSetupInProgress()
 {
@@ -95,11 +94,6 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
 
     const int syncBookmarksTimeout = 100;
 
-    m_saveBookmarksTimer = new QTimer(this);
-    m_saveBookmarksTimer->setInterval(syncBookmarksTimeout);
-    m_saveBookmarksTimer->setSingleShot(true);
-    connect(m_saveBookmarksTimer, SIGNAL(timeout()), this, SLOT(saveBookmarks()));
-
     m_updateBookmarksTimer = new QTimer(this);
     m_updateBookmarksTimer->setInterval(syncBookmarksTimeout);
     m_updateBookmarksTimer->setSingleShot(true);
@@ -113,7 +107,6 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
 
 PlacesItemModel::~PlacesItemModel()
 {
-    saveBookmarks();
     qDeleteAll(m_bookmarkedItems);
     m_bookmarkedItems.clear();
 }
@@ -498,8 +491,6 @@ void PlacesItemModel::onItemInserted(int index)
         m_bookmarkedItems.insert(bookmarkIndex, 0);
     }
 
-    triggerBookmarksSaving();
-
 #ifdef PLACESITEMMODEL_DEBUG
     kDebug() << "Inserted item" << index;
     showModelState();
@@ -518,8 +509,6 @@ void PlacesItemModel::onItemRemoved(int index, KStandardItem* removedItem)
     Q_ASSERT(!m_bookmarkedItems[boomarkIndex]);
     m_bookmarkedItems.removeAt(boomarkIndex);
 
-    triggerBookmarksSaving();
-
 #ifdef PLACESITEMMODEL_DEBUG
     kDebug() << "Removed item" << index;
     showModelState();
@@ -549,8 +538,6 @@ void PlacesItemModel::onItemChanged(int index, const QSet<QByteArray>& changedRo
             QTimer::singleShot(0, this, SLOT(hideItem()));
         }
     }
-
-    triggerBookmarksSaving();
 }
 
 void PlacesItemModel::slotDeviceAdded(const QString& udi)
@@ -1033,20 +1020,12 @@ void PlacesItemModel::hideItem(int index)
             // bookmark should still be remembered, so readd it again:
             m_bookmarkManager->root().addBookmark(hiddenBookmark);
             m_bookmarkManager->root().moveBookmark(hiddenBookmark, previousBookmark);
-            triggerBookmarksSaving();
         }
 
         m_bookmarkedItems.insert(newIndex, hiddenItem);
     }
 }
 
-void PlacesItemModel::triggerBookmarksSaving()
-{
-    if (m_saveBookmarksTimer) {
-        m_saveBookmarksTimer->start();
-    }
-}
-
 QString PlacesItemModel::internalMimeType() const
 {
     return "application/x-dolphinplacesmodel-" +
