@@ -33,13 +33,13 @@ class QLabel;
 class QVBoxLayout;
 
 /**
- * @brief Input box for searching files with or without Nepomuk.
+ * @brief Input box for searching files with or without Baloo.
  *
  * The widget allows to specify:
  * - Where to search: Everywhere or below the current directory
  * - What to search: Filenames or content
  *
- * If Nepomuk is available and the current folder is indexed, further
+ * If Baloo is available and the current folder is indexed, further
  * options are offered.
  */
 class DolphinSearchBox : public QWidget {
@@ -71,22 +71,17 @@ public:
     /** @return URL that will start the searching of files. */
     KUrl urlForSearching() const;
 
+    /**
+     * Extracts information from the given search \a url to
+     * initialize the search box properly.
+     */
+    void fromSearchUrl(const KUrl& url);
+
     /**
      * Selects the whole text of the search box.
      */
     void selectAll();
 
-    /**
-     * @param readOnly If set to true the searchbox cannot be modified
-     *                 by the user and acts as visual indicator for
-     *                 an externally triggered search query.
-     * @param query    If readOnly is true this URL will be used
-     *                 to show a human readable information about the
-     *                 query.
-     */
-    void setReadOnly(bool readOnly, const KUrl& query = KUrl());
-    bool isReadOnly() const;
-
     /**
      * Set the search box to the active mode, if \a active
      * is true. The active mode is default. The inactive mode only differs
@@ -151,16 +146,19 @@ private:
     void init();
 
     /**
-     * @return URL that represents the Nepomuk query for starting the search.
+     * @return URL that represents the Baloo query for starting the search.
      */
-    KUrl nepomukUrlForSearching() const;
+    KUrl balooUrlForSearching() const;
 
-    void applyReadOnlyState();
+    /**
+     * Extracts information from the given Baloo search \a url to
+     * initialize the search box properly.
+     */
+    void fromBalooSearchUrl(const KUrl& url);
 
     void updateFacetsToggleButton();
 private:
     bool m_startedSearching;
-    bool m_readOnly;
     bool m_active;
 
     QVBoxLayout* m_topLayout;
@@ -177,7 +175,6 @@ private:
     DolphinFacetsWidget* m_facetsWidget;
 
     KUrl m_searchPath;
-    KUrl m_readOnlyQuery;
 
     QTimer* m_startSearchTimer;
 };
